function varargout = deGUI(varargin)
%      Differential Equation Graphical User Interface
%
%      The deGUI graphical user interface allows the user to enter a 
%      second order nonlinear differential equation, initial values,
%      time steps, and plot the results in a phase portrait and time series.
%
%      Copyright 2017 Jocelyn Kluger and Themis Sapsis
%      For comments or questions, contact jociek@alum.mit.edu
%
%      Please cite as:
%      Kluger, J., Sapsis T., "Differential Equation Graphical
%      User Interface," 2017, http://jocelynkluger.com/deGUI.htm.
%      Accessed <date>


% Begin initialization code
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @deGUI_OpeningFcn, ...
                   'gui_OutputFcn',  @deGUI_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code


% --- Executes just before deGUI is made visible.
function deGUI_OpeningFcn(hObject, eventdata, handles, varargin)

cla(handles.axes1)
cla(handles.axes2)

% Choose default command line output for deGUI
handles.output = hObject;

%new variables
handles.trackInd= 1;
handles.trackVector= 'bgrcmy';
handles.xpMaxOld= 1;
handles.xpMinOld= -1;
handles.xMaxOld= 1;
handles.xMinOld= -1;
handles.tminInOld= 0;
handles.tmaxInOld= 1;
handles.xminIn_TimeOld= 0;
handles.xMaxIn_timeOld= 1;

guidata(hObject, handles);

set(gcf, 'WindowButtonDownFcn', @getMousePositionOnImage);



% --- Outputs from this function are returned to the command line.
function varargout = deGUI_OutputFcn(hObject, eventdata, handles)
varargout{1} = handles.output;

% --- Executes on button press in UpdateButton.
function UpdateButton_Callback(hObject, eventdata, handles)
        runAnyFcn(hObject, eventdata, handles);
      
function endTimeInput_Callback(hObject, eventdata, handles)
        
function timeStepInput_Callback(hObject, eventdata, handles)

function x0input_Callback(hObject, eventdata, handles)
        
function xp0input_Callback(hObject, eventdata, handles)

function eqnInput_Callback(hObject, eventdata, handles)

% --------------------------------------------------------------------
function OpenMenuItem_Callback(hObject, eventdata, handles)
% hObject    handle to OpenMenuItem (see GCBO)
% eventdata  reserved - to be defined in eqnInput future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
file = uigetfile('*.fig');
if ~isequal(file, 0)
    open(file);
end

% --------------------------------------------------------------------
function PrintMenuItem_Callback(hObject, eventdata, handles)
% hObject    handle to PrintMenuItem (see GCBO)
% eventdata  reserved - to be defined in eqnInput future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
printdlg(handles.figure1)

% --------------------------------------------------------------------
function CloseMenuItem_Callback(hObject, eventdata, handles)
% hObject    handle to CloseMenuItem (see GCBO)
% eventdata  reserved - to be defined in eqnInput future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
selection = questdlg(['Close ' get(handles.figure1,'Name') '?'],...
                     ['Close ' get(handles.figure1,'Name') '...'],...
                     'Yes','No','Yes');
if strcmp(selection,'No')
    return;
end

delete(handles.figure1)


% --- Executes during object creation, after setting all properties.
function eqnInput_CreateFcn(hObject, eventdata, handles)
% hObject    handle to eqnInput (see GCBO)
% eventdata  reserved - to be defined in eqnInput future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have eqnInput white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes during object creation, after setting all properties.
function UpdateButton_CreateFcn(hObject, eventdata, handles)
% hObject    handle to UpdateButton (see GCBO)
% eventdata  reserved - to be defined in eqnInput future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function endTimeInput_CreateFcn(hObject, eventdata, handles)
% hObject    handle to endTimeInput (see GCBO)
% eventdata  reserved - to be defined in eqnInput future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have eqnInput white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes during object creation, after setting all properties.
function x0input_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes during object creation, after setting all properties.
function xp0input_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% --- Executes during object creation, after setting all properties.
function timeStepInput_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function xMinIn_Callback(hObject, eventdata, handles)
xMin= str2num(handles.xMinIn.String);
xMax= str2num(handles.xMaxIn.String);
axes(handles.axes1);
hold on
if xMin < xMax
    xlim([xMin xMax]);
    setAxesFcn(hObject, eventdata, handles, xMin, xMax, [], [], [], [], [], []);   
else %otherwise, force displayed text to remain the same
   xMax= handles.xMaxOld;
   xMin= handles.xMinOld;
   handles.xMaxIn.String= handles.xMaxOld;
   handles.xMinIn.String= handles.xMinOld;
end
handles.xMaxOld= xMax; %update tracked values
handles.xMinOld= xMin;
guidata(hObject,handles)


% --- Executes during object creation, after setting all properties.
function xMinIn_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function xMaxIn_Callback(hObject, eventdata, handles)
xMin= str2num(handles.xMinIn.String);
xMax= str2num(handles.xMaxIn.String);
axes(handles.axes1);
hold on
if xMin < xMax
    xlim([xMin xMax]);
    setAxesFcn(hObject, eventdata, handles, xMin, xMax, [], [], [], [], [], []);   
else %otherwise, force displayed text to remain the same
   xMax= handles.xMaxOld;
   xMin= handles.xMinOld;
   handles.xMaxIn.String= handles.xMaxOld;
   handles.xMinIn.String= handles.xMinOld;
end
handles.xMaxOld= xMax; %update tracked values
handles.xMinOld= xMin;
guidata(hObject,handles)

% --- Executes during object creation, after setting all properties.
function xMaxIn_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function xpMinIn_Callback(hObject, eventdata, handles)
xpMin= str2num(handles.xpMinIn.String);
xpMax= str2num(handles.xpMaxIn.String);
axes(handles.axes1);
hold on
if xpMax > xpMin
ylim([xpMin xpMax]);
setAxesFcn(hObject, eventdata, handles, [], [], xpMin, xpMax, [], [], [], []);
else
   xpMax= handles.xpMaxOld;
   xpMin= handles.xpMinOld;
   handles.xpMaxIn.String= handles.xpMaxOld;
   handles.xpMinIn.String= handles.xpMinOld;
end
handles.xpMaxOld= xpMax; %update tracked values
handles.xpMinOld= xpMin;
guidata(hObject,handles)



% --- Executes during object creation, after setting all properties.
function xpMinIn_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function xpMaxIn_Callback(hObject, eventdata, handles)
xpMin= str2num(handles.xpMinIn.String);
xpMax= str2num(handles.xpMaxIn.String);
axes(handles.axes1);
hold on
if xpMax > xpMin %If valid input
ylim([xpMin xpMax]); %update y limit values
setAxesFcn(hObject, eventdata, handles, [], [], xpMin, xpMax, [], [], [], []);


else %otherwise, force displayed text to remain the same
   xpMax= handles.xpMaxOld;
   xpMin= handles.xpMinOld;
   handles.xpMaxIn.String= handles.xpMaxOld;
   handles.xpMinIn.String= handles.xpMinOld;
end
handles.xpMaxOld= xpMax; %update tracked values
handles.xpMinOld= xpMin;
guidata(hObject,handles)



% --- Executes during object creation, after setting all properties.
function xpMaxIn_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function getMousePositionOnImage(src, event, hObject)

handles = guidata(src);

cursorPoint = get(handles.axes1, 'CurrentPoint');
curX = cursorPoint(1,1);
curY = cursorPoint(1,2);

xLimits = get(handles.axes1, 'xlim');
yLimits = get(handles.axes1, 'ylim');

if (curX > min(xLimits) && curX < max(xLimits) && curY > min(yLimits) && curY < max(yLimits))
    set(handles.x0input, 'String', num2str(curX, 3)); %set x0 value
    set(handles.xp0input, 'String', num2str(curY, 3)); %set xp0 value

    %If cursor is in phase plot 1
    runAnyFcn(src, event, handles);
end


% --- Executes on button press in clearButton.
function clearButton_Callback(hObject, eventdata, handles)
cla(handles.axes1)
cla(handles.axes2)

handles.trackInd= 1;
guidata(hObject,handles)



function runAnyFcn(hObject, eventdata, handles)
%plot trajectory of function

textInput= handles.eqnInput.String;
endTime= str2num(handles.endTimeInput.String);
dT= str2num(handles.timeStepInput.String);
x01= str2num(handles.x0input.String);
xp0= str2num(handles.xp0input.String);

x0= [x01 xp0];

%Example: Duffing oscillator: x'' + dx + ax + bx^3 = gamma*cos(wt)

tspan= [0:dT:endTime];

%Replace x' with xp:
%First- modify input to satisfy format
    %remove periods if user used .* or ./ or .^
text= strrep(textInput, '.*', '*');
text= strrep(text, './', '/');
text= strrep(text, '.^', '^');


handles.Warning.Visible= 'Off';
handles.Error1.Visible= 'Off';
handles.Error2.Visible= 'Off';
handles.Error3.Visible= 'Off';


%Don't allow any apostrophes except for x'.
%if there's an apostrophe.
%move along string
   
i= 1;
while i< length(text)
   if text(i)=='''' && text(i+1)==''''
       text(i+1)= [];
       %Look at new element to right
       
       handles.Warning.Visible= 'On';
   else
   i= i+1;
   end
   handles.eqnInput.String= text; %update displayed text
end

text= strrep(text, 'x''', 'xp');
text= strrep(text, '*', '.*');
text= strrep(text, '/', './');
text= strrep(text, '^', '.^');


try
    [t, x]= ode45(@(t,x) odefcnAny(t, x, text), tspan, x0);
catch
    %Display message:
    %Error in input equation.
    %Only variables allowed: t, x, x'.
    %Require MATLAB-friendly operators: *, /, +, -, sin(), cos(), exp(), log(), ...
    handles.Error1.Visible= 'On';
    handles.Error2.Visible= 'On';
    handles.Error3.Visible= 'On';
end
X= x(:,1);
Xp= x(:,2);

lineStr= strcat('-', handles.trackVector(handles.trackInd));

axes(handles.axes2);
% hold off
h= plot(t,X,lineStr); %curve
hold on
g= plot(t,X,'-oy','MarkerSize',5,'MarkerFaceColor','r'); %end point
q= plot(t(1),X(1),'-oy','MarkerSize',5,'MarkerFaceColor',[0 0.5 0]); %Start point

%Current axis limits
axes(handles.axes2);
origTmin= handles.axes2.XLim(1);
origTmax= handles.axes2.XLim(2);
origXMinTime= handles.axes2.YLim(1);
origXMaxTime= handles.axes2.YLim(2);

%Compare new values with new plotted values
minTshow= min(origTmin, 0);
maxTshow= max(origTmax, t(end));
minXshow= min(origXMinTime, min(X));
maxXshow= max(origXMaxTime, max(X));
axis([minTshow maxTshow minXshow maxXshow])

set(gca,'Color',[0 0 0])

axes(handles.axes1);
% hold off
k= plot(X,Xp,lineStr); %curve
hold on
m= plot(X,Xp,'-oy','MarkerSize',5,'MarkerFaceColor','r'); %End point
n= plot(X(1),Xp(1),'-oy','MarkerSize',5,'MarkerFaceColor',[0 0.5 0]); %start point
set(gca,'Color',[0 0 0])

if handles.trackInd <6
    handles.trackInd= handles.trackInd+1;
else
    handles.trackInd= 1;
end
    guidata(hObject,handles)


%% %Manually entered values for time series. Equal Current xlims
%Current xlims
origXmin= handles.axes1.XLim(1);
origXmax= handles.axes1.XLim(2);
origXpMin= handles.axes1.YLim(1);
origXpMax= handles.axes1.YLim(2);

%change text display of values
newXmin= min(origXmin, min(X));
newXmax= max(origXmax, max(X));
newXpMin= min(origXpMin, min(Xp));
newXpMax= max(origXpMax, max(Xp));

% %Implement possible changes to axis limits
xlim([newXmin newXmax]);
% set(handles.xMaxIn,'String', num2str(newXmax, 3));
% set(handles.xMinIn, 'String', num2str(newXmin, 3));
% xVector= linspace(newXmin,newXmax,5);
% xVector= xVector(2:4);
% xticks(xVector);

ylim([newXpMin newXpMax]);
% set(handles.xpMaxIn, 'String', num2str(newXpMax, 3));
% set(handles.xpMinIn, 'String', num2str(newXpMin,3));
% xpVector= linspace(newXpMin,newXpMax,5);
% % xpVector= xpVector(2:4);
% yticks(xpVector);

%%
setAxesFcn(hObject, eventdata, handles, newXmin, newXmax, newXpMin, newXpMax, minTshow, maxTshow, minXshow, maxXshow)
%%


for i=1:length(t)
    axes(handles.axes2);
    set(h, 'xdata', t(1:i), 'ydata', X(1:i));
    set(g, 'xdata', t(i), 'ydata', X(i));
    %pause(.000001) %Too slow
    
    axes(handles.axes1);
    set(k, 'xdata', X(1:i), 'ydata', Xp(1:i));
    set(m, 'xdata', X(i), 'ydata', Xp(i));
    
    drawnow
    
end






function dydt = odefcnAny(t,xIn,textInput)
x= xIn(1);
xp= xIn(2);

dydt = zeros(2,1);
dydt(1) = xIn(2);
dydt(2) = -eval(textInput);



function xMaxIn_time_Callback(hObject, eventdata, handles)
xMaxIn_time= str2num(handles.xMaxIn_time.String);
xminIn_Time= str2num(handles.xminIn_Time.String);
axes(handles.axes2);
hold on
if xMaxIn_time > xminIn_Time
    ylim([xminIn_Time xMaxIn_time]);
    setAxesFcn(hObject, eventdata, handles, [], [], [], [], [], [], xminIn_Time, xMaxIn_time);
else
   xMaxIn_time= handles.xMaxIn_timeOld;
   xminIn_Time= handles.xminIn_TimeOld;
   handles.xMaxIn_time.String= handles.xMaxIn_timeOld;
   handles.xminIn_Time.String= handles.xminIn_TimeOld;
end
handles.xMaxIn_timeOld= xMaxIn_time; %update tracked values
handles.xminIn_TimeOld= xminIn_Time;
guidata(hObject,handles)




% --- Executes during object creation, after setting all properties.
function xMaxIn_time_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function tminIn_Callback(hObject, eventdata, handles)
tMaxIn_time= str2num(handles.tmaxIn.String);
tMinIn_Time= str2num(handles.tminIn.String);
axes(handles.axes2);
hold on
if tMaxIn_time > tMinIn_Time
    xlim([tMinIn_Time tMaxIn_time]);
    setAxesFcn(hObject, eventdata, handles, [], [], [], [], tMinIn_Time, tMaxIn_time, [], []);
else
   tMinIn_Time= handles.tminInOld;
   tMaxIn_time= handles.tmaxInOld;
   handles.tmaxIn.String= handles.tmaxInOld;
   handles.tminIn.String= handles.tminInOld;
end
handles.tmaxInOld= tMaxIn_time; %update tracked values
handles.tminInOld= tMinIn_Time;
guidata(hObject,handles)

% --- Executes during object creation, after setting all properties.
function tminIn_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function tmaxIn_Callback(hObject, eventdata, handles)
tMaxIn_time= str2num(handles.tmaxIn.String);
tMinIn_Time= str2num(handles.tminIn.String);
axes(handles.axes2);
hold on
if tMaxIn_time > tMinIn_Time
    xlim([tMinIn_Time tMaxIn_time]);
    setAxesFcn(hObject, eventdata, handles, [], [], [], [], tMinIn_Time, tMaxIn_time, [], []);
else
   tMinIn_Time= handles.tminInOld;
   tMaxIn_time= handles.tmaxInOld;
   handles.tmaxIn.String= handles.tmaxInOld;
   handles.tminIn.String= handles.tminInOld;
end
handles.tmaxInOld= tMaxIn_time; %update tracked values
handles.tminInOld= tMinIn_Time;
guidata(hObject,handles)





% --- Executes during object creation, after setting all properties.
function tmaxIn_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function xminIn_Time_Callback(hObject, eventdata, handles)
xMaxIn_time= str2num(handles.xMaxIn_time.String);
xminIn_Time= str2num(handles.xminIn_Time.String);
axes(handles.axes2);
hold on
if xMaxIn_time > xminIn_Time
    ylim([xminIn_Time xMaxIn_time]);
    setAxesFcn(hObject, eventdata, handles, [], [], [], [], [], [], xminIn_Time, xMaxIn_time);
else
   xMaxIn_time= handles.xMaxIn_timeOld;
   xminIn_Time= handles.xminIn_TimeOld;
   handles.xMaxIn_time.String= handles.xMaxIn_timeOld;
   handles.xminIn_Time.String= handles.xminIn_TimeOld;
end
handles.xMaxIn_timeOld= xMaxIn_time; %update tracked values
handles.xminIn_TimeOld= xminIn_Time;
guidata(hObject,handles)



% --- Executes during object creation, after setting all properties.
function xminIn_Time_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --------------------------------------------------------------------
function uipushtool2_ClickedCallback(hObject, eventdata, handles)
fprintf('Save Figures')


% --------------------------------------------------------------------
function plotsButton_ClickedCallback(hObject, eventdata, handles)
fh = figure;


handleTemp= copyobj(handles.axes1, fh);
handleTemp.Position= [0.1 0.1 0.8 0.8];
title('Phase Portrait');
xlabel('x');
ylabel('x''');
set(gca, 'XTickMode', 'auto')
set(gca, 'XTickLabelMode', 'auto');
set(gca, 'YTickMode', 'auto')
set(gca, 'YTickLabelMode', 'auto');

%Change background to white
set(gca, 'Color', [1 1 1]);



fh2 = figure;
handleTemp2= copyobj(handles.axes2, fh2);
title('Time Series');
xlabel('t');
ylabel('x');
handleTemp2.Units= 'normalized';
handleTemp2.Position= [0.1 0.1 0.8 0.8];

set(gca, 'XTickMode', 'auto')
set(gca, 'XTickLabelMode', 'auto');
set(gca, 'YTickMode', 'auto')
set(gca, 'YTickLabelMode', 'auto');

%Change background to white
set(gca, 'Color', [1 1 1]);




% --------------------------------------------------------------------
function uitoggletool3_OffCallback(hObject, eventdata, handles)
%Current axis limits
newXmin= handles.axes1.XLim(1);
newXmax= handles.axes1.XLim(2);
newXpMin= handles.axes1.YLim(1);
newXpMax= handles.axes1.YLim(2);


%Current axis limits
newTmin= handles.axes2.XLim(1);
newTmax= handles.axes2.XLim(2);
newXtMin= handles.axes2.YLim(1);
newXtMax= handles.axes2.YLim(2);

setAxesFcn(hObject, eventdata, handles, newXmin, newXmax, newXpMin, newXpMax, newTmin, newTmax, newXtMin, newXtMax)

% Update handles structure
guidata(hObject, handles);




function setAxesFcn(hObject, eventdata, handles, newXmin, newXmax, newXpMin, newXpMax, newTmin, newTmax, newXminTime, newXmaxTime)

if ~isempty(newXmax)
    %Implement possible changes
    set(handles.xMaxIn,'String', sprintf('%.4g', newXmax ));
    set(handles.xMinIn, 'String', sprintf('%.4g', newXmin) );
    xVector= linspace(newXmin,newXmax,5);
    set(handles.axes1, 'XTick', xVector);

    xString2= sprintf('%.4g', xVector(2));
    xString3= sprintf('%.4g', xVector(3));
    xString4= sprintf('%.4g', xVector(4));
    xtickLabelVector= {'' xString2 xString3 xString4 ''};
    set(handles.axes1, 'XTickLabel', xtickLabelVector);
end

if ~isempty(newXpMax)
    set(handles.xpMaxIn, 'String', sprintf('%.4g', newXpMax));
    set(handles.xpMinIn, 'String', sprintf('%.4g', newXpMin));
    xpVector= linspace(newXpMin,newXpMax,5);
    set(handles.axes1, 'YTick', xpVector);
    
    xpString2= sprintf('%.4g', xpVector(2));
    xpString3= sprintf('%.4g', xpVector(3));
    xpString4= sprintf('%.4g', xpVector(4));
    xptickLabelVector= {'' xpString2 xpString3 xpString4 ''};
    set(handles.axes1, 'YTickLabel', xptickLabelVector);
end


if ~isempty(newXmaxTime)
    %Implement possible changes
    set(handles.xMaxIn_time,'String', sprintf('%.4g',newXmaxTime));
    set(handles.xminIn_Time, 'String',sprintf('%.4g',newXminTime));
    xVector= linspace(newXminTime,newXmaxTime,5);
    set(handles.axes2, 'YTick', xVector);

    xString2= sprintf('%.4g', xVector(2));
    xString3= sprintf('%.4g', xVector(3));
    xString4= sprintf('%.4g', xVector(4));
    
    ytickLabelVector= {'' xString2 xString3 xString4 ''};
    set(handles.axes2, 'YTickLabel', ytickLabelVector);
end

if ~isempty(newTmax)
    set(handles.tminIn, 'String', sprintf('%.4g',newTmin));
    set(handles.tmaxIn, 'String', sprintf('%.4g',newTmax));
    TVector= linspace(newTmin,newTmax,5);
    set(handles.axes2, 'XTick', TVector);
    
    TString2= sprintf('%.4g', TVector(2));
    TString3= sprintf('%.4g', TVector(3));
    TString4= sprintf('%.4g', TVector(4));
    TtickLabelVector= {'' TString2 TString3 TString4 ''};
    set(handles.axes2, 'XTickLabel', TtickLabelVector);
end


% Update handles structure
guidata(hObject, handles);
